summaryrefslogtreecommitdiff
path: root/src/exchange/taler-exchange-httpd_keystate.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/exchange/taler-exchange-httpd_keystate.h')
-rw-r--r--src/exchange/taler-exchange-httpd_keystate.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/exchange/taler-exchange-httpd_keystate.h b/src/exchange/taler-exchange-httpd_keystate.h
index 004ce5014..b7e5b10fb 100644
--- a/src/exchange/taler-exchange-httpd_keystate.h
+++ b/src/exchange/taler-exchange-httpd_keystate.h
@@ -110,14 +110,14 @@ enum TEH_KS_DenominationKeyUse
TEH_KS_DKU_DEPOSIT,
/**
* The key is to be used for a /payback operation.
*/
- TEH_KS_DKU_PAYBACK,
+ TEH_KS_DKU_RECOUP,
/**
* The key is to be used for a /refresh/payback operation,
* i.e. it is an old coin that regained value from a
* payback on a new coin derived from the old coin.
*/
TEH_KS_DKU_ZOMBIE
@@ -110,14 +110,14 @@ enum TEH_KS_DenominationKeyUse
TEH_KS_DKU_DEPOSIT,
/**
- * The key is to be used for a /payback operation.
+ * The key is to be used for a /recoup operation.
*/
@@ -110,14 +110,14 @@ enum TEH_KS_DenominationKeyUse
/**
- * The key is to be used for a /refresh/payback operation,
+ * The key is to be used for a /refresh/recoup operation,
* i.e. it is an old coin that regained value from a
@@ -110,14 +110,14 @@ enum TEH_KS_DenominationKeyUse
* i.e. it is an old coin that regained value from a
- * payback on a new coin derived from the old coin.
+ * recoup on a new coin derived from the old coin.
*/
TEH_KS_DKU_ZOMBIE